<?php

/**
 * Plugin Name: Rentware Widgets for Elementor
 * Description: Integrate Rentware seamlessly into your Elementor-powered WordPress site with our Rentware Elementor Addon. Effortlessly create and manage rental listings, booking forms, and availability calendars directly within the Elementor Page Builder.
 * Version:     1.0.0
 * Author:      Rentware.com
 * Author URI:  https://rentware.com/
 * Plugin URI:  https://rentware.com/integrationen/wordpress-elementor-plugin/
 * Text Domain: rentware-addon-for-elementor
 * License:     GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

function register_rentware_for_elementor_widget($widgets_manager)
{

	require_once(__DIR__ . '/widgets/checkout.php');
	require_once(__DIR__ . '/widgets/search.php');
	require_once(__DIR__ . '/widgets/article-booking.php');
	require_once(__DIR__ . '/widgets/article-details.php');

	$widgets_manager->register(new \Rentware_Checkout());
	$widgets_manager->register(new \Rentware_Search());
	$widgets_manager->register(new \Rentware_Article_Booking());
	$widgets_manager->register(new \Rentware_Article_Details());
}
add_action('elementor/widgets/register', 'register_rentware_for_elementor_widget');

/**
 * Add Rentware as a new category in the Elementor editor after the Basic category.
 */

function rtr_add_elementor_widget_categories($elements_manager)
{

	$categories = [];
	$old_categories = $elements_manager->get_categories();

	foreach ($old_categories as $key => $category) {
		$categories[$key] = $category;
		if ($key == 'basic') {
			$categories['rentware'] =
				[
					'title' => esc_html__('Rentware', 'rentware-addon-for-elementor'),
					'icon' => 'fa fa-plug',
				];
		}
	}

	$set_categories = function ($categories) {
		$this->categories = $categories;
	};

	$set_categories->call($elements_manager, $categories);
}

add_action('elementor/elements/categories_registered', 'rtr_add_elementor_widget_categories');



/**
 * Register Rentware scripts.
 * <script
 *  type="module"
 *  src="https://cdn.rtr-io.com/widgets.js"
 * ></script>
 */
function rtr_rentware_widgets_dependencies()
{

	/* Rentware Scripts */
	wp_register_script(
		'rtr-io.com',
		'https://cdn.rtr-io.com/widgets.js',
		[],
		null,
		[
			'defer' => true,
			'in_footer' => true,
		]
	);
}

add_action('wp_enqueue_scripts', 'rtr_rentware_widgets_dependencies');



/**
 * Add type="module" to the Rentware script tag.
 */
function rtr_rentware_widgets_script_loader_tag($tag, $handle, $src)
{
	if ('rtr-io.com' === $handle) {
		$tag = '<script type="module" src="' . esc_url($src) . '" ></script>';
	}

	return $tag;
}
add_filter('script_loader_tag', 'rtr_rentware_widgets_script_loader_tag', 10, 3);
