<?php

if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

class Rentware_Checkout extends \Elementor\Widget_Base
{

  public function get_script_depends()
  {
    return ['rtr-io.com'];
  }

  public function get_name()
  {
    return 'rentware_checkout';
  }

  public function get_title()
  {
    return esc_html__('Rentware Checkout', 'rentware-addon-for-elementor');
  }

  public function get_icon()
  {
    return 'eicon-cart-medium';
  }

  public function get_categories()
  {
    return ['rentware'];
  }

  public function get_keywords()
  {
    return ['rentware', 'checkout'];
  }

  protected function register_controls()
  {

    // Settings Tab Start

    $this->start_controls_section(
      'section_title',
      [
        'label' => esc_html__('Settings', 'rentware-addon-for-elementor'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    // add description that access token can be found in the rentware backend
    $this->add_control(
      'access_token',
      [
        'label' => esc_html__(
          'Access Token',
          'rentware-addon-for-elementor'
        ),
        'label_block' => true,
        'description' => esc_html__('You can find the access token in the rentware backend', 'rentware-addon-for-elementor'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('W13573b675870ceec4d127c520ce42e2d', 'rentware-addon-for-elementor'),
        'dynamic' => [
          'active' => true,
        ],
        'ai' => false,
      ]
    );

    $this->add_control(
      'locale',
      [
        'label' => esc_html__('Language', 'rentware-addon-for-elementor'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => esc_html__('de-DE', 'rentware-addon-for-elementor'),
        'default' => esc_html__('de-DE', 'rentware-addon-for-elementor'),
        'dynamic' => [
          'active' => true,
        ],
        'ai' => false,
      ]
    );

    $this->end_controls_section();

    // Settings Tab End

  }

  protected function render()
  {
    $settings = $this->get_settings_for_display();

    if (empty($settings['access_token'])) {
      return;
    }
?>
    <script>
      window.RTR_ACCESS_TOKEN = '<?php echo $settings['access_token']; ?>'
      window.RTR_LOCALE = '<?php echo $settings['locale']; ?>'
    </script>
    <rtr-checkout></rtr-checkout>

  <?php
  }

  protected function _content_template()
  {
  ?>
    <# if (settings.access_token) { #>
      <rtr-checkout></rtr-checkout>
      <# } else { #>
        <div class="elementor-alert elementor-alert-warning">
          <?php esc_html_e('Please enter an access token in the settings.', 'rentware-addon-for-elementor'); ?>
        </div>
        <# } #>
          <script>
            window.RTR_ACCESS_TOKEN = '{{{ settings.access_token }}}'
            window.RTR_LOCALE = '{{{ settings.locale }}}'
          </script>
      <?php

    }
  }
